@@ -631,7 +631,10 @@ void YWindowManager::handleMapRequest(const XMapRequestEvent &mapRequest) {
 void YWindowManager::handleUnmap(const XUnmapEvent &unmap) {
 #if 1
     if (unmap.send_event)
-        xapp->handleWindowEvent(unmap.window, *(XEvent *)&unmap);
+        if (unmap.window != handle())
+            xapp->handleWindowEvent(unmap.window, *(XEvent *)&unmap);
+        else
+            MSG(("unhandled root window unmap"));
 #endif
 }
 
@@ -1205,6 +1208,7 @@ void YWindowManager::setWindows(YFrameWindow **w, int count, YAction *action) {
         }
     }
     unlockFocus();
+    focusTopWindow();
 }
 
 void YWindowManager::getNewPosition(YFrameWindow *frame, int &x, int &y, int w, int h, int xiscreen) {
@@ -1472,6 +1476,8 @@ YFrameWindow *YWindowManager::manageClient(Window win, bool mapClient) {
 #endif
         if (frame->frameOptions() & YFrameWindow::foMinimized) {
             frame->setState(WinStateMinimized, WinStateMinimized);
+            doActivate = false;
+            requestFocus = false;
         }
     }
 
@@ -1506,6 +1512,8 @@ YFrameWindow *YWindowManager::manageClient(Window win, bool mapClient) {
             if (canManualPlace && opaqueMove)
                 frame->wmMove();
         } else if (requestFocus) {
+            if (mapInactiveOnTop)
+                frame->wmRaise();
             frame->setWmUrgency(true);
         }
     }
@@ -2718,14 +2726,16 @@ void YWindowManager::handleRRScreenChangeNotify(const XRRScreenChangeNotifyEvent
     XRRUpdateConfiguration((XEvent *)&xrrsc);
 #endif
 
-    if (width() != xrrsc.width ||
-        height() != xrrsc.height)
+    int nw = DisplayWidth(xapp->display(), DefaultScreen(xapp->display()));
+    int nh = DisplayHeight(xapp->display(), DefaultScreen(xapp->display()));
+    if (width() != nw ||
+        height() != nh)
     {
 
         MSG(("xrandr: %d %d",
-             xrrsc.width,
-             xrrsc.height));
-        setSize(xrrsc.width, xrrsc.height);
+             nw,
+             nh));
+        setSize(nw, nh);
         updateXineramaInfo();
         updateWorkArea();
 #ifdef CONFIG_TASKBAR
