@@ -7,6 +7,7 @@ XIV(bool, dontRotateMenuPointer,                true)
 XIV(bool, menuMouseTracking,                    false)
 XIV(bool, replayMenuCancelClick,                false)
 XIV(bool, showPopupsAbovePointer,               false)
+XIV(bool, showEllipsis,                         true)
 #ifdef CONFIG_I18N
 XIV(bool, multiByte,                            true)
 #endif
@@ -53,6 +54,7 @@ XSV(const char *, themeName,                    CONFIG_DEFAULT_THEME)
 #define CONFIG_LOOK_PIXMAP
 #define CONFIG_LOOK_METAL
 #define CONFIG_LOOK_GTK
+#define CONFIG_LOOK_FLAT
 
 #ifndef WMLOOK
 #define WMLOOK
@@ -80,6 +82,9 @@ typedef enum {
 #endif
 #ifdef CONFIG_LOOK_GTK
     lookGtk,
+#endif
+#ifdef CONFIG_LOOK_FLAT
+    lookFlat,
 #endif
     lookMAX
 } WMLook;
@@ -151,6 +156,14 @@ XIV(WMLook, wmLook,                             CONFIG_DEFAULT_LOOK)
 #define CASE_LOOK_GTK
 #endif
 
+#ifdef CONFIG_LOOK_FLAT
+#define LOOK_IS_FLAT            (wmLook == lookFlat)
+#define CASE_LOOK_FLAT          case lookFlat
+#else
+#define LOOK_IS_FLAT false
+#define CASE_LOOK_FLAT
+#endif
+
 #ifdef CONFIG_TOOLTIP
 XSV(const char *, clrToolTip,                   "rgb:E0/E0/00")
 XSV(const char *, clrToolTipText,               "rgb:00/00/00")
