@@ -115,7 +115,8 @@ unsigned int ignore_enternotify_hack = 0; // credits to ahwm
 
 static void update_ignore_enternotify_hack(const XEvent &event) {
     ignore_enternotify_hack = event.xany.serial;
-    XSync(xapp->display(), False);
+    if (xapp && xapp->display())
+        XSync(xapp->display(), False);
 }
 
 /******************************************************************************/
@@ -1616,13 +1617,16 @@ void YWindow::grabVKey(int key, unsigned int vm) {
        m |= xapp->SuperMask;
     if (vm & kfHyper)
        m |= xapp->HyperMask;
+    if (vm & kfAltGr)
+        m |= xapp->ModeSwitchMask;
 
     MSG(("grabVKey %d %d %d", key, vm, m));
     if (key != 0 && (vm == 0 || m != 0)) {
         if ((!(vm & kfMeta) || xapp->MetaMask) &&
             (!(vm & kfAlt) || xapp->AltMask) &&
            (!(vm & kfSuper) || xapp->SuperMask) &&
-            (!(vm & kfHyper) || xapp->HyperMask))
+            (!(vm & kfHyper) || xapp->HyperMask) &&
+            (!(vm & kfAltGr) || xapp->ModeSwitchMask))
         {
             grabKey(key, m);
         }
@@ -1639,6 +1643,8 @@ void YWindow::grabVKey(int key, unsigned int vm) {
                 m |= xapp->SuperMask;
             if (vm & kfHyper)
                 m |= xapp->HyperMask;
+            if (vm & kfAltGr)
+                m |= xapp->ModeSwitchMask;
             grabKey(key, m);
         }
     }
@@ -1659,6 +1665,8 @@ void YWindow::grabVButton(int button, unsigned int vm) {
        m |= xapp->SuperMask;
     if (vm & kfHyper)
        m |= xapp->HyperMask;
+    if (vm & kfAltGr)
+       m |= xapp->ModeSwitchMask;
 
     MSG(("grabVButton %d %d %d", button, vm, m));
 
@@ -1666,7 +1674,8 @@ void YWindow::grabVButton(int button, unsigned int vm) {
         if ((!(vm & kfMeta) || xapp->MetaMask) &&
             (!(vm & kfAlt) || xapp->AltMask) &&
            (!(vm & kfSuper) || xapp->SuperMask) &&
-            (!(vm & kfHyper) || xapp->HyperMask))
+            (!(vm & kfHyper) || xapp->HyperMask) &&
+            (!(vm & kfAltGr) || xapp->ModeSwitchMask))
         {
             grabButton(button, m);
         }
@@ -1683,6 +1692,8 @@ void YWindow::grabVButton(int button, unsigned int vm) {
                 m |= xapp->SuperMask;
             if (vm & kfHyper)
                 m |= xapp->HyperMask;
+            if (vm & kfAltGr)
+                m |= xapp->ModeSwitchMask;
             grabButton(button, m);
         }
     }
@@ -1712,6 +1723,8 @@ unsigned int YWindow::VMod(int m) {
        vm |= kfSuper;
     if (m1 & xapp->HyperMask)
        vm |= kfHyper;
+    if (m1 & xapp->ModeSwitchMask)
+       vm |= kfAltGr;
 
     return vm;
 }
